@@ -1,8 +1,8 @@
-/// This module is responsible for translating PRQL AST to sqlparser AST, and
-/// then to a String. We use sqlparser because it's trivial to create the string
-/// once it's in their AST (it's just `.to_string()`). It also lets us support a
-/// few dialects of SQL immediately.
-// The average code quality here is quite low — we're basically plugging in test
+//! This module is responsible for translating PRQL AST to sqlparser AST, and
+//! then to a String. We use sqlparser because it's trivial to create the string
+//! once it's in their AST (it's just `.to_string()`). It also lets us support a
+//! few dialects of SQL immediately.
+// The average code quality here is low — we're basically plugging in test
 // cases and fixing what breaks, with some occasional refactors. I'm not sure
 // that's a terrible approach — the SQL spec is huge, so we're not reasonably
 // going to be isomorphically mapping everything back from SQL to PRQL. But it
@@ -19,7 +19,7 @@ use sqlparser::ast::{
 };
 use std::collections::HashMap;
 
-/// Translate a PRQL AST to SQL string.
+/// Translate a PRQL AST into a SQL string.
 pub fn translate(ast: &Item) -> Result<String> {
     let sql_query: sqlparser::ast::Query = ast
         .as_query()
@@ -180,7 +180,7 @@ fn select_columns_of_pipeline(pipeline: &Pipeline) -> Result<Vec<SelectItem>> {
         }
     }
     if is_inclusive {
-        selects.push(SelectItem::Wildcard);
+        selects.insert(0, SelectItem::Wildcard);
     }
 
     Ok(selects)
@@ -812,6 +812,61 @@ take 20
         let sql = translate(&ast)?;
         assert_display_snapshot!(sql);
 
+        // table
+        let query = parse(
+            r#"
+        table newest_employees = (
+            from employees
+            sort tenure
+            take 50
+        )
+        table average_salaries = (
+            from salaries
+            aggregate by:country [
+                average_country_salary: average salary
+            ]
+        )
+        from newest_employees
+        join average_salaries [country]
+        select [name, salary, average_country_salary]
+    "#,
+        )?;
+        let ast = materialize(query)?;
+        let sql = translate(&ast)?;
+        assert_display_snapshot!(sql,
+            @r###"
+        WITH newest_employees AS (
+          SELECT
+            TOP (50) *
+          FROM
+            employees
+          ORDER BY
+            tenure
+        ),
+        average_salaries AS (
+          SELECT
+            AVG(salary) AS average_country_salary
+          FROM
+            salaries
+          GROUP BY
+            country
+        ),
+        table_0 AS (
+          SELECT
+            name,
+            salary,
+            average_country_salary
+          FROM
+            newest_employees
+            JOIN average_salaries ON country
+        )
+        SELECT
+          *
+        FROM
+          table_0
+        "###
+        );
+
         Ok(())
     }
 
